<?php

/**
 * BUDDYPRESS CUBEPOINTS FUNCTIONS
 *
 * @version 0.1.9.3
 * @since 1.0
 * @package BuddyPress CubePoints
 * @subpackage Main
 * @license GPL v2.0
 * @link http://wordpress.org/extend/plugins/cubepoints-buddypress-integration/
 *
 * ========================================================================================================
 */

/**
 * my_bp_admin_bar_points()
 *
 * Display points earned in the admin bar
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_admin_bar_points() {

	global $bp;

	if(cp_module_activated('donate')){
	    
		echo '<li class="no-arrow">';
		?><a href="#" title="<?php _e('Donate', 'cp'); ?>" onclick="Javascript:cp_module_donate();" class="thickbox cp_donateLink">
		<?php echo cp_displayPoints();
		echo '</a></li>';
	}
	else {
		echo '<li class="no-arrow">';
		?><a href="<?php bloginfo('url'); echo '/'.BP_MEMBERS_SLUG.'/'; echo bp_loggedin_user_username(); echo '/'.$bp->cubepoint->slug.'/'; ?>">
		<?php echo cp_displayPoints();
		echo '</a></li>';
	}		
		
		
}

/**
 * my_bp_create_group_add_cppoints()
 *
 * Add Points for creating a group
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_create_group_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_group_create', $bp->loggedin_user->id, get_option('bp_create_group_add_cp_bp'), "");
	}

}

/**
 * my_bp_delete_group_add_cppoints()
 *
 * Remove points for deleting a group
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_delete_group_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}
	
	if( $bp->loggedin_user->is_super_admin ){
		return false;
	}

	if ($is_spammer == false) {
		cp_points('cp_bp_group_delete', $bp->loggedin_user->id, get_option('bp_delete_group_add_cp_bp'), "");
	}

}

/**
 * my_bp_update_post_add_cppoints()
 *
 * Add Points for a update
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_update_post_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
		    
			$is_spammer = true;
			
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_update', $bp->loggedin_user->id, get_option('bp_update_post_add_cp_bp'), "");
	}

}

/**
 * my_bp_join_group_add_cppoints()
 *
 * Points for Joining a group
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_join_group_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_group_joined', $bp->loggedin_user->id, get_option('bp_join_group_add_cp_bp'), "");
	}

}

/**
 * my_bp_leave_group_add_cppoints()
 *
 * Points for Leaving a group
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_leave_group_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_group_left', $bp->loggedin_user->id, get_option('bp_leave_group_add_cp_bp'), "");
	}

}


/**
 * my_bp_update_comment_add_cppoints()
 *
 * Add Points for a comment or reply
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_update_comment_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_reply', $bp->loggedin_user->id, get_option('bp_update_comment_add_cp_bp'), "");
	}

}

/**
 * my_bp_update_group_add_cppoints()
 *
 * Add Points for a GROUP comment or reply
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_update_group_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_group_reply', $bp->loggedin_user->id, get_option('bp_update_group_add_cp_bp'), "");
	}

}

/**
 * my_bp_delete_comment_add_cppoints()
 *
 * Remove points for comment deletion
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_delete_comment_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if( $bp->loggedin_user->is_super_admin ){
		return false;
	}

	if ($is_spammer == false) {
		cp_points('cp_bp_update_removed', $bp->loggedin_user->id, get_option('bp_delete_comment_add_cp_bp'), "");
	}
}

/**
 * my_bp_friend_add_cppoints()
 *
 * Add Points for a completed Friend Request
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_friend_add_cppoints($friendship_id, $inviter_id, $invitee_id) {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach( $bpcpspamlist as $spammer_id ) {

		if($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}
	}

	if ($is_spammer == false) {
		cp_points('cp_bp_new_friend', $inviter_id, get_option('bp_friend_add_cp_bp'), "");
		cp_points('cp_bp_new_friend', $invitee_id, get_option('bp_friend_add_cp_bp'), "");		
	}

}

/**
 * my_bp_friend_delete_add_cppoints()
 *
 * Remove points for Canceled Friendship 
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_friend_delete_add_cppoints($friendship_id, $initiator_userid, $friend_userid) {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if($is_spammer == false) {
		cp_points('cp_bp_lost_friend', $initiator_userid, get_option('bp_friend_delete_add_cp_bp'), "");
		cp_points('cp_bp_lost_friend', $friend_userid, get_option('bp_friend_delete_add_cp_bp'), "");		
	}
}


/**
 * my_bp_forum_new_topic_add_cppoints()
 *
 * Add Points New Group Forum Topic (See FAQ in readme.txt for more info)
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_forum_new_topic_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_new_group_forum_topic', $bp->loggedin_user->id, get_option('bp_forum_new_topic_add_cp_bp'), "");		
	}

}

/**
 * my_bp_forum_new_post_add_cppoints()
 *
 * Add Points New Group Forum Post
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_forum_new_post_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_new_group_forum_post', $bp->loggedin_user->id, get_option('bp_forum_new_post_add_cp_bp'), "");		
	}

}

/**
 * my_bp_forum_edit_topic_add_cppoints()
 *
 * POINTS FIX for New Forum Topic Edit
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_forum_edit_topic_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_new_group_forum_post_edit', $bp->loggedin_user->id, -get_option('bp_forum_new_post_add_cp_bp'), "");
	}

}

/**
 * my_bp_forum_edit_post_add_cppoints()
 *
 * POINTS FIX for Forum Post Editit
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_forum_edit_post_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_new_group_forum_post_edit', $bp->loggedin_user->id, -get_option('bp_forum_new_post_add_cp_bp'), "");
	}

}

/**
 * my_bp_avatar_add_cppoints()
 *
 * Add Points Avatar Upload
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_avatar_add_cppoints() {

	global $bp;
	global $wpdb;

	define('CUBEPTS2', $wpdb->prefix . 'cubepoints');
	define('CUBEPTS3', $wpdb->prefix . 'cp');

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );
	$avatar_results = $wpdb->get_var("SELECT COUNT(*) FROM ".CUBEPTS2." WHERE type='Avatar Uploaded' AND uid = ".$bp->loggedin_user->id);
	$avatar_results2 = $wpdb->get_var("SELECT COUNT(*) FROM ".CUBEPTS3." WHERE type='cp_bp_avatar_uploaded' AND uid = ".$bp->loggedin_user->id);
	$avatar_results = $avatar_results + $avatar_results2;

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}
	}
	
	if($is_spammer == false) {

		if($avatar_results < 1) {
			cp_points('cp_bp_avatar_uploaded', $bp->loggedin_user->id, get_option('bp_avatar_add_cp_bp'), "");			
		}

	}
}

/**
 * my_bp_group_avatar_add_cppoints()
 *
 * Add Points Group Avatar Upload
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_group_avatar_add_cppoints() {

	global $bp;
	global $wpdb;

	define('BBCPDB', $wpdb->prefix . 'bp_activity');
	define('CUBEPTS2', $wpdb->prefix . 'cubepoints');
	define('CUBEPTS3', $wpdb->prefix . 'cp');

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );
	$bp_cp_xgroups_created = $wpdb->get_var("SELECT COUNT(*) FROM ".BBCPDB." WHERE type='created_group' AND user_id = ".$bp->loggedin_user->id);
	$group_avatar_results = $wpdb->get_var("SELECT COUNT(*) FROM ".CUBEPTS2." WHERE type='Group Avatar Uploaded' AND uid = ".$bp->loggedin_user->id);
	$group_avatar_results2 = $wpdb->get_var("SELECT COUNT(*) FROM ".CUBEPTS3." WHERE type='cp_bp_group_avatar_uploaded' AND uid = ".$bp->loggedin_user->id);
	$group_avatar_results = $group_avatar_results + $group_avatar_results2;

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}
	
	if ($is_spammer == false) {

		if($bp_cp_xgroups_created > $group_avatar_results) {
			cp_points('cp_bp_group_avatar_uploaded', $bp->loggedin_user->id, get_option('bp_avatar_add_cp_bp'), "");			
		}

	}

}

/**
 * my_bp_pm_cppoints()
 *
 * Add Point Message Sent
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_pm_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_message_sent', $bp->loggedin_user->id, get_option('bp_pm_cp_bp'), "");
	}

}

/**
 * my_bp_bplink_add_cppoints()
 *
 * Add Points for BuddyPress Link Creation
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_bplink_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}
	}

	if ($is_spammer == false) {
		cp_points('cp_bp_link_added', $bp->loggedin_user->id, get_option('bp_bplink_add_cp_bp'), "");
	}

}

/**
 * my_bp_bplinkvote_add_cppoints()
 *
 * Add Points for BuddyPress Link Vote
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_bplinkvote_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_link_voted', $bp->loggedin_user->id, get_option('bp_bplink_vote_add_cp_bp'), "");
	}

}

/**
 * my_bp_bplinkcomment_add_cppoints()
 *
 * Add Points for BuddyPress Link Comment/Update
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_bplinkcomment_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_link_comment', $bp->loggedin_user->id, get_option('bp_bplink_comment_add_cp_bp'), "");
	}
}

/**
 * my_bp_bplink_delete_add_cppoints()
 *
 * Add Points for BuddyPress Link Delete
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_bplink_delete_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_link_delete', $bp->loggedin_user->id, get_option('bp_bplink_delete_add_cp_bp'), "");
	}

}

/**
 * my_bp_gift_given_add_cppoints()
 *
 * Add Points for BuddyPress Gifts
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_gift_given_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_gift_given', $bp->loggedin_user->id, get_option('bp_gift_given_cp_bp'), "");		
	}

}

/**
 * my_bp_gallery_upload_add_cppoints()
 *
 * Add Points for BP Gallery Upload
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_gallery_upload_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_galery_upload', $bp->loggedin_user->id, get_option('bp_gallery_upload_cp_bp'), "");
	}

}

/**
 * my_bp_gallery_delete_add_cppoints()
 *
 * Remove Points for BP Gallery Delete
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function my_bp_gallery_delete_add_cppoints() {

	global $bp;

	$bpcpspamlist = explode(',' , get_option( 'bp_spammer_cp_bp' ) );

	foreach ( $bpcpspamlist as $spammer_id ) {

		if ($bp->loggedin_user->id == $spammer_id ) {	
			$is_spammer = true;
			break;
		}
		else {
			$is_spammer = false;
		}

	}

	if ($is_spammer == false) {
		cp_points('cp_bp_galery_delete', $bp->loggedin_user->id, get_option('bp_gallery_delete_cp_bp'), "");
	}

}

/**
 * cubepoints_bp_profile() 
 *
 * Adds CubePoints to Profile Page
 * 
 *  @version 1.9.3
 *  @since 1.0
 */
function cubepoints_bp_profile() {

	global $bp;

	if(function_exists('cp_displayPoints')){ ?>
		<span class="cubepoints_buddypress"><?php echo cp_displayPoints($bp->displayed_user->id); ?></span>
	<?php }

	if(cp_module_activated('donate')){
		if (is_user_logged_in()) { ?>
			<span class="cupepoints_buddypress_donate"><a href="#" title="<?php _e('Donate', 'cp'); ?>" onclick="Javascript:cp_module_donate();" class="thickbox cp_donateLink">Donate Points</a></span>
	<?php } }

	if(cp_module_activated('ranks')){ ?>
		<span class="cupepoints_buddypress_rank">Rank - <?php echo cp_module_ranks_getRank($bp->displayed_user->id); ?></span>
	<?php }
	
}

?>